@@ -1,5 +1,5 @@
 /*******************************************************************************
-* Copyright 2022-2024 Intel Corporation
+* Copyright 2022-2025 Intel Corporation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
@@ -43,7 +43,6 @@ status_t gen_reorder_t::pd_t::init(impl::engine_t *engine,
     const auto dst_dt = dst_md()->data_type;
     auto *compute_engine = utils::downcast<compute::compute_engine_t *>(engine);
     auto *device_info = compute_engine->device_info();
-    zero_points_config_t zp_cfg(this);
     using namespace data_type;
 
     auto post_ops_ok = [&]() {
@@ -62,11 +61,6 @@ status_t gen_reorder_t::pd_t::init(impl::engine_t *engine,
         return (attr()->scales_.get(DNNL_ARG_SRC).mask_ == 0)
                 && (attr()->scales_.get(DNNL_ARG_DST).mask_ == 0);
     };
-    auto zps_ok = [&]() {
-        return (!zp_cfg.do_src_compensation || zp_cfg.is_common_src_zero_point)
-                && (!zp_cfg.do_dst_compensation
-                        || zp_cfg.is_common_dst_zero_point);
-    };
     auto is_bf16_or_f32_or_f8 = [](data_type_t dt) {
         return utils::one_of(dt, bf16, f32, f8_e5m2, f8_e4m3);
     };
@@ -77,9 +71,6 @@ status_t gen_reorder_t::pd_t::init(impl::engine_t *engine,
                         || utils::one_of(src_dt, bf16, f16, f32)
                         || utils::one_of(dst_dt, bf16, f16, f32));
     };
-    auto skip_mask = dnnl_primitive_attr::skip_mask_t::post_ops
-            | dnnl_primitive_attr::skip_mask_t::zero_points_runtime
-            | dnnl_primitive_attr::skip_mask_t::scales_runtime;
     VDISPATCH_REORDER(
             src_engine == dst_engine && src_engine->kind() == engine_kind::gpu,
             VERBOSE_BAD_ENGINE_KIND);
@@ -102,11 +93,23 @@ status_t gen_reorder_t::pd_t::init(impl::engine_t *engine,
     VDISPATCH_REORDER(IMPLICATION(src_dt == f64 || dst_dt == f64,
                               device_info->has_native(f64)),
             VERBOSE_UNSUPPORTED_DT_CFG);
+    using sm = dnnl_primitive_attr::skip_mask_t;
+    auto skip_mask = sm::post_ops | sm::zero_points_runtime | sm::scales_runtime
+            | sm::rounding_mode;
     VDISPATCH_REORDER(
             attr()->has_default_values(skip_mask), VERBOSE_UNSUPPORTED_ATTR);
-    VDISPATCH_REORDER(extra_ok(), VERBOSE_UNSUPPORTED_MD_FLAG, "extra_ok");
+    VDISPATCH_REORDER(extra_ok(true), VERBOSE_UNSUPPORTED_MD_FLAG, "extra_ok");
     VDISPATCH_REORDER(post_ops_ok(), VERBOSE_UNSUPPORTED_POSTOP);
     VDISPATCH_REORDER(scales_ok(), VERBOSE_UNSUPPORTED_SCALES_CFG);
+
+    // Create `zp_cfg` object after all relevant zp checks passing to avoid
+    // potential issues with the generator for unsupported features.
+    zero_points_config_t zp_cfg(this);
+    auto zps_ok = [&]() {
+        return (!zp_cfg.do_src_compensation || zp_cfg.is_common_src_zero_point)
+                && (!zp_cfg.do_dst_compensation
+                        || zp_cfg.is_common_dst_zero_point);
+    };
     VDISPATCH_REORDER(zps_ok(), VERBOSE_UNSUPPORTED_ZP_CFG);
     VDISPATCH_REORDER(hf8_ok(), VERBOSE_UNSUPPORTED_DT);
 
@@ -145,6 +148,7 @@ status_t gen_reorder_t::pd_t::init(impl::engine_t *engine,
             check_layout(dst_layout), VERBOSE_UNSUPPORTED_TENSOR_LAYOUT, "dst");
     VDISPATCH_REORDER(compute_engine->mayiuse_ngen_kernels(),
             VERBOSE_UNSUPPORTED_DEVICE_FEATURE, "ngen_kernels");
+
     auto *gpu_attr
             = utils::downcast<gpu_primitive_attr_t *>(attr()->gpu_attr_.get());
     hw_t hw(engine);
@@ -155,7 +159,8 @@ status_t gen_reorder_t::pd_t::init(impl::engine_t *engine,
     cfg->set_zp_cfg(zp_cfg);
     VDISPATCH_REORDER_SC(
             init_kernel_info(), "kernel initialization unsuccessful");
-
+    VDISPATCH_REORDER_SC(maybe_create_zp_precompute_conv_pd(dst_engine),
+            "failed to create nested zp precompute convolution");
     return status::success;
 }
 
@@ -199,6 +204,9 @@ status_t gen_reorder_t::pd_t::init_kernel_info() {
 }
 
 status_t gen_reorder_t::init(impl::engine_t *engine) {
+    CHECK(pd()->maybe_create_zp_precompute_conv(
+            zp_precomp_conv_, engine, this));
+
     auto &cfg = *pd()->cfg;
     auto &info = *pd()->kernel_info;
 
@@ -218,6 +226,7 @@ status_t gen_reorder_t::execute(const exec_ctx_t &ctx) const {
     info.set_args(arg_list, storage_list);
 
     CHECK(parallel_for(ctx, info.nd_range(), kernel_, arg_list));
+    CHECK(pd()->maybe_exec_zp_precompute_conv(ctx, zp_precomp_conv_));
     return status::success;
 }
 
