@@ -32,6 +32,7 @@
 #include "common/utils.hpp"
 #include "gpu/intel/compute/device_info.hpp"
 #include "gpu/intel/jit/ngen/ngen.hpp"
+#include "gpu/intel/serialization.hpp"
 #include "gpu/intel/utils.hpp"
 
 #ifdef DNNL_DEV_MODE
@@ -133,6 +134,16 @@ size_t get_hash(const std::vector<T> &v) {
     return h;
 }
 
+template <typename Key, typename T, typename Compare, typename Allocator>
+size_t get_hash(const std::map<Key, T, Compare, Allocator> &m) {
+    size_t h = 0;
+    for (auto &kv : m) {
+        h = hash_combine(h, get_hash(kv.first));
+        h = hash_combine(h, get_hash(kv.second));
+    }
+    return h;
+}
+
 template <typename... ArgsT>
 size_t get_hash(const ArgsT &...args) {
     size_t h = 0;
@@ -786,7 +797,7 @@ inline void idiv_magicgu(uint32_t d, uint32_t &m, uint32_t &p) {
     for (p = 32; p < 64; p++) {
         uint64_t _2p = 1LL << p;
         if (_2p > nc * (d - 1 - (_2p - 1) % d)) {
-            m = (_2p + d - 1 - (_2p - 1) % d) / d;
+            m = into<uint32_t>((_2p + d - 1 - (_2p - 1) % d) / d);
             return;
         }
     }
@@ -805,10 +816,11 @@ inline uint64_t idiv_magicgu_packed(uint32_t d) {
 
 // Calculate how many unique filter padding states a conv dimension can produce
 // (see conv_post_op_view_mapper_t for more context)
-inline int max_unique_pad_states(int O, int I, int KD, int P, int S, bool lim) {
-    int retn = 1;
+inline dim_t max_unique_pad_states(
+        dim_t O, dim_t I, dim_t KD, dim_t P, dim_t S, bool lim) {
+    dim_t retn = 1;
     if (I > KD) {
-        retn += std::min((O - 1) * S - P, 0)
+        retn += std::min((O - 1) * S - P, dim_t(0))
                 + std::max((O - 1) * S + (KD - P), I) + (P - I);
     } else { // I <= KD, no two states are the same
         retn += (O - 1) * S;
@@ -901,6 +913,7 @@ static auto hw_names = nstl::to_array({
         make_enum_name(ngen::Core::XeHPG, "xehpg"),
         make_enum_name(ngen::Core::XeHPC, "xehpc"),
         make_enum_name(ngen::Core::Xe2, "xe2"),
+        make_enum_name(ngen::Core::Xe3, "xe3"),
 });
 GPU_DEFINE_PARSE_ENUM(ngen::HW, hw_names)
 
@@ -918,6 +931,7 @@ static auto product_family_names = nstl::to_array({
         make_enum_name(ngen::ProductFamily::GenericXeHPC, "xehpc"),
         make_enum_name(ngen::ProductFamily::PVC, "pvc"),
         make_enum_name(ngen::ProductFamily::GenericXe2, "xe2"),
+        make_enum_name(ngen::ProductFamily::GenericXe3, "xe3"),
 });
 GPU_DEFINE_PARSE_ENUM(ngen::ProductFamily, product_family_names)
 
@@ -1079,6 +1093,26 @@ class parse_iface_t {
 public:
     using base_type = T;
 
+    struct entry_t {
+        std::string name;
+        std::string help;
+        std::string _default;
+        bool required = false;
+        std::function<void(std::ostream &, const T &)> stringify;
+        std::function<void(std::istream &, T &)> parse;
+
+        bool matches_relaxed(const std::string &_s) const {
+            auto s = (_s.find("--") == 0 ? _s.substr(2) : _s);
+            if (s.length() != name.length()) return false;
+            for (size_t i = 0; i < s.length(); i++) {
+                if (s[i] == name[i]) continue;
+                if (s[i] == '-' && name[i] == '_') continue;
+                return false;
+            }
+            return true;
+        }
+    };
+
     template <typename U, U T::*ptr>
     void add(const std::string &name = {}, const std::string &help = {},
             bool required = false) {
@@ -1093,6 +1127,10 @@ public:
         e.parse = [](std::istream &in, T &parent) {
             jit::parse(in, parent.*ptr);
         };
+        add(e);
+    }
+
+    void add(const entry_t &e) {
         if (relaxed_) {
             ir_assert(!e.name.empty())
                     << "Relaxed support requires non-empty name.";
@@ -1174,26 +1212,6 @@ public:
     }
 
 private:
-    struct entry_t {
-        std::string name;
-        std::string help;
-        std::string _default;
-        bool required = false;
-        std::function<void(std::ostream &, const T &)> stringify;
-        std::function<void(std::istream &, T &)> parse;
-
-        bool matches_relaxed(const std::string &_s) const {
-            auto s = (_s.find("--") == 0 ? _s.substr(2) : _s);
-            if (s.length() != name.length()) return false;
-            for (size_t i = 0; i < s.length(); i++) {
-                if (s[i] == name[i]) continue;
-                if (s[i] == '-' && name[i] == '_') continue;
-                return false;
-            }
-            return true;
-        }
-    };
-
     int find_entry_index(const std::string name) const {
         for (int i = 0; i < (int)entries_.size(); i++) {
             if (entries_[i].matches_relaxed(name)) return i;
@@ -1326,6 +1344,30 @@ void stringify_to_cpp_file(const std::string &file_name,
         const std::string &var_name, const std::vector<std::string> &namespaces,
         const std::vector<std::string> &lines);
 
+template <typename T>
+std::string serialize_to_hex(const T &t) {
+    std::ostringstream oss;
+    serialized_data_t s;
+    s.append(t);
+    for (uint8_t d : s.get_data()) {
+        oss << std::uppercase << std::hex << std::setw(2) << std::setfill('0')
+            << (int)d;
+    }
+    return oss.str();
+}
+
+template <typename T>
+void deserialize_from_hex(T &t, const std::string &s_hex) {
+    std::vector<uint8_t> data;
+    for (size_t i = 0; i < s_hex.size(); i += 2) {
+        data.push_back(static_cast<uint8_t>(
+                std::stoi(s_hex.substr(i, 2), nullptr, 16)));
+    }
+    auto s = serialized_t::from_data(std::move(data));
+    deserializer_t d(s);
+    d.pop(t);
+}
+
 } // namespace jit
 } // namespace intel
 } // namespace gpu
