@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright 2022-2024 Intel Corporation
+ * Copyright 2022-2025 Intel Corporation
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -48,11 +48,12 @@ using value_ptr = std::shared_ptr<value_t>;
 using ltw = logical_tensor_wrapper_t;
 
 subgraph_t::subgraph_t(const std::vector<op_ptr> &ops, const dnnl::engine &eng,
-        impl::fpmath_mode_t fpm_mode, bool can_use_blocked_layout,
+        const graph::fpmath_t &fpm_mode, bool can_use_blocked_layout,
         bool reset_layout)
-    : graph_t(ops, static_cast<engine_kind_t>(eng.get_kind()), fpm_mode)
+    : graph_t(ops, static_cast<engine_kind_t>(eng.get_kind()))
     , p_engine_(&eng)
     , fusion_info_mgr_(fpm_mode, can_use_blocked_layout) {
+    set_fpmath_mode(fpm_mode.mode_, fpm_mode.apply_to_int_);
     if (reset_layout) { set_all_layout_to_any(get_mutable_ops()); }
 }
 
@@ -384,10 +385,6 @@ void subgraph_rewriter_t::run() {
     to_be_inserted_ops_.clear();
 }
 
-subgraph_rewriter_t::~subgraph_rewriter_t() {
-    run();
-}
-
 void subgraph_rewriter_t::fuse_op_to_successor(const op_ptr &op) {
     assertm(op->num_inputs() == 1, "this op should have only one input value.");
     value_ptr in_val = op->get_input_value(0);
@@ -446,6 +443,26 @@ void subgraph_rewriter_t::insert_op_before(const op_ptr &inserted_op,
     auto in_dtype = in_val->get_logical_tensor().data_type;
     new_val->set_data_type(in_dtype);
 
+    if (inserted_op->get_kind() == op_kind::dnnl_permute
+            && (base_op->get_kind() == op_kind::dnnl_mul_scales
+                    || base_op->get_kind() == op_kind::dnnl_sub_zps)) {
+        // Only abx tag is respected for scale and zps inputs, should set
+        // strides explicitly and execute reorder.
+
+        dnnl::memory::desc in_md
+                = make_dnnl_memory_desc(in_val->get_logical_tensor());
+        const auto &perm = inserted_op->get_attr<std::vector<int64_t>>(
+                op_attr::permutation);
+        std::vector<int> int_perm(perm.size(), -1);
+        for (size_t i = 0; i < perm.size(); i++) {
+            int_perm[i] = static_cast<int>(perm[i]);
+        }
+        dnnl::memory::desc out_md = in_md.permute_axes(int_perm);
+        const auto &dims = out_md.get_dims();
+        // set the strides with abx tag.
+        new_val->set_strides(get_dense_strides(dims));
+    }
+
     if (k == std::numeric_limits<size_t>::max()) {
         k = inserted_op->num_outputs();
     }
