@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright 2020-2024 Intel Corporation
+ * Copyright 2020-2025 Intel Corporation
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -125,7 +125,7 @@ static brgemm_attr_t get_dnnl_brgemm_attrs(const attrs_setting_t &attrs) {
                         = static_cast<brgemm_kernel_prefetching_t>(it.second);
                 break;
             case attr_key::wary_tail_read:
-                dnnl_attrs.wary_tail_read = static_cast<bool>(it.second);
+                dnnl_attrs.wary_A_k_tail_read = static_cast<bool>(it.second);
                 break;
             case attr_key::generate_skip_accumulation:
                 dnnl_attrs.generate_skip_accumulation
@@ -196,7 +196,7 @@ static dnnl::impl::post_ops_t get_dnnl_postops_setting(
         if (alg == alg_kind_t::bias_add) {
             bias_dt = convert_dnnl_dtype(static_cast<int>(op.bias_op_.dtype_));
         } else if (alg == alg_kind_t::out_scales) {
-            status = pattr.output_scales_.set(op.scale_op_.scale_);
+            assert(!"unsupported quantization");
         } else if (alg == alg_kind_t::a_zp) {
             status = pattr.zero_points_.set(DNNL_ARG_SRC, op.zp_op_.zp_);
         } else if (alg == alg_kind_t::b_zp) {
@@ -825,7 +825,7 @@ SC_API void dnnl_brgemm_call(brgemm_kernel_info *brg_desc, const void *A,
         brgemm_batch_element_t *batch = (brgemm_batch_element_t *)_malloca(
                 num * sizeof(brgemm_batch_element_t));
 #else
-#if SC_IS_DPCPP() || (defined(CLANGVERSION) && CLANGVERSION <= 3)
+#if SC_IS_DPCPP()
         std::unique_ptr<brgemm_batch_element_t[]> batch_v(
                 new brgemm_batch_element_t[num]);
         brgemm_batch_element_t *batch = batch_v.get();
@@ -876,7 +876,7 @@ SC_API void dnnl_brgemm_call_postops(brgemm_kernel_info *brg_desc,
         brgemm_batch_element_t *batch = (brgemm_batch_element_t *)_malloca(
                 num * sizeof(brgemm_batch_element_t));
 #else
-#if SC_IS_DPCPP() || (defined(CLANGVERSION) && CLANGVERSION <= 3)
+#if SC_IS_DPCPP()
         std::unique_ptr<brgemm_batch_element_t[]> batch_v(
                 new brgemm_batch_element_t[num]);
         brgemm_batch_element_t *batch = batch_v.get();
@@ -930,7 +930,7 @@ SC_API void dnnl_brgemm_list_call(brgemm_kernel_info *brg_desc,
     brgemm_batch_element_t *batch = (brgemm_batch_element_t *)_malloca(
             batch_num * sizeof(brgemm_batch_element_t));
 #else
-#if SC_IS_DPCPP() || (defined(CLANGVERSION) && CLANGVERSION <= 3)
+#if SC_IS_DPCPP()
     std::unique_ptr<brgemm_batch_element_t[]> batch_v(
             new brgemm_batch_element_t[batch_num]);
     brgemm_batch_element_t *batch = batch_v.get();
@@ -995,7 +995,7 @@ SC_API void dnnl_brgemm_list_call_postops(brgemm_kernel_info *brg_desc,
     brgemm_batch_element_t *batch = (brgemm_batch_element_t *)_malloca(
             batch_num * sizeof(brgemm_batch_element_t));
 #else
-#if SC_IS_DPCPP() || (defined(CLANGVERSION) && CLANGVERSION <= 3)
+#if SC_IS_DPCPP()
     std::unique_ptr<brgemm_batch_element_t[]> batch_v(
             new brgemm_batch_element_t[batch_num]);
     brgemm_batch_element_t *batch = batch_v.get();
@@ -1087,7 +1087,7 @@ SC_API int dnnl_brgemm_init_update(const void *A, const void *B, void *C,
         brgemm_batch_element_t *batch = (brgemm_batch_element_t *)_malloca(
                 batch_num * sizeof(brgemm_batch_element_t));
 #else
-#if SC_IS_DPCPP() || (defined(CLANGVERSION) && CLANGVERSION <= 3)
+#if SC_IS_DPCPP()
         std::unique_ptr<brgemm_batch_element_t[]> batch_v(
                 new brgemm_batch_element_t[batch_num]);
         brgemm_batch_element_t *batch = batch_v.get();
@@ -1154,7 +1154,7 @@ SC_API int dnnl_brgemm_update(const void *A, const void *B, void *C, int num,
         brgemm_batch_element_t *batch = (brgemm_batch_element_t *)_malloca(
                 batch_num * sizeof(brgemm_batch_element_t));
 #else
-#if SC_IS_DPCPP() || (defined(CLANGVERSION) && CLANGVERSION <= 3)
+#if SC_IS_DPCPP()
         std::unique_ptr<brgemm_batch_element_t[]> batch_v(
                 new brgemm_batch_element_t[batch_num]);
         brgemm_batch_element_t *batch = batch_v.get();
@@ -1214,7 +1214,7 @@ static int dnnl_brgemm_list_update_func(const void **A_list,
     brgemm_batch_element_t *batch = (brgemm_batch_element_t *)_malloca(
             batch_num * sizeof(brgemm_batch_element_t));
 #else
-#if SC_IS_DPCPP() || (defined(CLANGVERSION) && CLANGVERSION <= 3)
+#if SC_IS_DPCPP()
     std::unique_ptr<brgemm_batch_element_t[]> batch_v(
             new brgemm_batch_element_t[batch_num]);
     brgemm_batch_element_t *batch = batch_v.get();
