@@ -1,5 +1,5 @@
 /*******************************************************************************
-* Copyright 2017-2024 Intel Corporation
+* Copyright 2017-2025 Intel Corporation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
@@ -210,7 +210,8 @@ int attr_t::policy2mask(int arg, policy_t policy,
             default: SAFE(FAIL, CRIT); return -1;
         }
     } else if (prim_kind == dnnl_matmul) {
-        if ((arg != DNNL_ARG_SRC && arg != DNNL_ARG_WEIGHTS)
+        if ((arg != DNNL_ARG_SRC && arg != DNNL_ARG_WEIGHTS
+                    && arg != DNNL_ARG_DST)
                 || policy == policy_t::COMMON)
             return attr_t::get_default_mask(policy);
 
@@ -219,6 +220,7 @@ int attr_t::policy2mask(int arg, policy_t policy,
             case PER_DIM_1:
             case PER_OC: return (1 << (ndims - 1));
             case PER_OCIC: return (1 << (ndims - 1)) + (1 << (ndims - 2));
+            case PER_TENSOR: return attr_t::get_default_mask(policy);
             default: SAFE_V(FAIL); return -1;
         }
     } else if (prim_kind == dnnl_layer_normalization) {
@@ -311,6 +313,7 @@ int attr_t::arg_scales_t::entry_t::from_str(const std::string &s) {
 
     if (!groups.empty()) {
         switch (this->policy) {
+            case PER_TENSOR:
             case PER_OC:
             case PER_OCIC:
                 if (this->groups.size() != 2) {
@@ -379,6 +382,8 @@ int attr_t::zero_points_t::entry_t::from_str(const std::string &s) {
             parser::parser_utils::stoll_safe, g_str, 'x');
     if (!groups.empty()) {
         switch (this->policy) {
+            case PER_TENSOR:
+            case PER_OC:
             case PER_OCIC:
                 if (this->groups.size() != 2) {
                     BENCHDNN_PRINT(0, "%s\n",
@@ -528,6 +533,7 @@ static po_table_entry_t kind_table[] = {
         {pk_t::MIN, {"min", "binary_min"}, dnnl_binary_min},
         {pk_t::MUL, {"mul", "binary_mul"}, dnnl_binary_mul},
         {pk_t::NE, {"ne", "binary_ne"}, dnnl_binary_ne},
+        {pk_t::SELECT, {"select", "binary_select"}, dnnl_binary_select},
         {pk_t::SUB, {"sub", "binary_sub"}, dnnl_binary_sub},
         {pk_t::BINARY_END, {"binary_undef"}, dnnl_alg_kind_undef},
         // prelu
@@ -624,7 +630,11 @@ bool attr_t::post_ops_t::entry_t::is_eltwise_kind() const {
     return kind > ELTWISE_START && kind < ELTWISE_END;
 }
 bool attr_t::post_ops_t::entry_t::is_binary_kind() const {
-    return kind > pk_t::BINARY_START && kind < pk_t::BINARY_END;
+    // binary select is a ternary operation and not currently
+    // supported in post-ops for the binary primitive
+    // TODO: add post-ops support for binary select operation
+    return kind > pk_t::BINARY_START && kind < pk_t::BINARY_END
+            && kind != pk_t::SELECT;
 }
 bool attr_t::post_ops_t::entry_t::is_prelu_kind() const {
     return kind == PRELU;
@@ -669,7 +679,7 @@ std::ostream &operator<<(
 
     s << scale.policy;
     if (scale.policy == policy_t::COMMON) s << ":" << scale.scale;
-    if (scale.dt != dnnl_f32) s << ':' << scale.dt;
+    if (scale.dt != dnnl_f32 || !scale.groups.empty()) s << ':' << scale.dt;
     if (!scale.groups.empty()) s << ":" << dims2str(scale.groups);
     return s;
 }
@@ -684,7 +694,8 @@ std::ostream &operator<<(
         s << arg2str(point.first) << ":" << point.second.policy;
         if (point.second.policy == policy_t::COMMON)
             s << ":" << point.second.value;
-        if (point.second.dt != dnnl_s32) s << ':' << point.second.dt;
+        if (point.second.dt != dnnl_s32 || !point.second.groups.empty())
+            s << ':' << point.second.dt;
         if (!point.second.groups.empty())
             s << ":" << dims2str(point.second.groups);
         delim = "+";
@@ -1572,7 +1583,7 @@ float compute_eltwise_bwd(
     return NAN;
 }
 
-float compute_binary(pk_t kind, float src0, float src1) {
+float compute_binary(pk_t kind, float src0, float src1, bool src2) {
     // don't compute on nan, propagate it
     if (std::isnan(src0) || std::isnan(src1)) return NAN;
 
@@ -1600,6 +1611,8 @@ float compute_binary(pk_t kind, float src0, float src1) {
         return src0 == src1;
     } else if (kind == pk_t::NE) {
         return src0 != src1;
+    } else if (kind == pk_t::SELECT) {
+        return src2 ? src0 : src1;
     } else {
         assert(!"operation not supported!");
     }
@@ -1659,7 +1672,7 @@ void maybe_post_ops(const attr_t &attr, float &val, float sum_val,
             const auto &b = e.eltwise.beta;
             val = compute_eltwise_fwd(e.kind, val, a, b);
         } else if (e.is_binary_kind()) {
-            val = compute_binary(e.kind, val, *it_po);
+            val = compute_binary(e.kind, val, *it_po, false);
             it_po++;
         } else if (e.is_prelu_kind()) {
             val = val > 0 ? val : val * (*it_po);
