@@ -1,5 +1,5 @@
 /*******************************************************************************
-* Copyright 2024 Intel Corporation
+* Copyright 2024-2025 Intel Corporation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
@@ -76,7 +76,7 @@ TEST(test_sdp_decomp_execute, F32SdpDecomp_CPU) {
             else
                 ASSERT_EQ(g.get_ops().size(), 6U);
 
-            graph::pass::pass_base_ptr apass = get_pass("float_sdp_fusion");
+            graph::pass::pass_base_ptr apass = get_pass("float_sdp_fusion_cpu");
             apass->run(g);
             ASSERT_EQ(g.get_num_partitions(), 1U);
             auto part = g.get_partitions()[0];
@@ -179,7 +179,7 @@ TEST(test_sdp_decomp_execute, Bf16SdpDecomp_CPU) {
             else
                 ASSERT_EQ(g.get_ops().size(), 6U);
 
-            graph::pass::pass_base_ptr apass = get_pass("float_sdp_fusion");
+            graph::pass::pass_base_ptr apass = get_pass("float_sdp_fusion_cpu");
             apass->run(g);
             ASSERT_EQ(g.get_num_partitions(), 1U);
             auto part = g.get_partitions()[0];
@@ -516,6 +516,7 @@ TEST(test_sdp_decomp_execute, MultithreaSdpDecomp_CPU) {
             graph::stream_t *strm;
             dnnl_stream_create(&strm, eng, dnnl_stream_in_order);
             std::vector<test_tensor> outputs_ts;
+            outputs_ts.reserve(partition_outputs.size());
             for (auto &lt : partition_outputs) {
                 outputs_ts.emplace_back(lt, eng);
             }
@@ -569,7 +570,7 @@ TEST(test_sdp_decomp_execute, F32SdpCorr_CPU) {
                     attention_mask_vec[j]);
             g.finalize();
 
-            graph::pass::pass_base_ptr apass = get_pass("float_sdp_fusion");
+            graph::pass::pass_base_ptr apass = get_pass("float_sdp_fusion_cpu");
             apass->run(g);
             ASSERT_EQ(g.get_num_partitions(), 1U);
             auto part = g.get_partitions()[0];
@@ -622,7 +623,7 @@ TEST(test_sdp_decomp_execute, F32SdpCorr_CPU) {
             }
 
             // -------------------------case 1----------------------------------
-            custom_setenv("_ONEDNN_ENABLE_SDP_DECOMP", "0", 1);
+            custom_setenv("_ONEDNN_GRAPH_SDPA_FORCE_PRIMITIVE", "1", 1);
             graph::compiled_partition_t cp1(p);
             ASSERT_EQ(p.compile(&cp1, inputs, outputs, eng),
                     graph::status::success);
@@ -638,7 +639,7 @@ TEST(test_sdp_decomp_execute, F32SdpCorr_CPU) {
             strm->wait();
 
             // -------------------------case 2----------------------------------
-            custom_setenv("_ONEDNN_ENABLE_SDP_DECOMP", "1", 1);
+            custom_setenv("_ONEDNN_GRAPH_SDPA_FORCE_PRIMITIVE", "0", 1);
             graph::compiled_partition_t cp2(p);
             ASSERT_EQ(p.compile(&cp2, inputs, outputs, eng),
                     graph::status::success);
@@ -687,7 +688,7 @@ TEST(test_sdp_decomp_execute, F32DistilBertSdpCorr_CPU) {
                 batch_size, seq_len, num_head, head_dim, transpose_b[i]);
         g.finalize();
 
-        graph::pass::pass_base_ptr apass = get_pass("float_sdp_fusion");
+        graph::pass::pass_base_ptr apass = get_pass("float_sdp_fusion_cpu");
         apass->run(g);
         ASSERT_EQ(g.get_num_partitions(), 1U);
         auto part = g.get_partitions()[0];
@@ -738,7 +739,7 @@ TEST(test_sdp_decomp_execute, F32DistilBertSdpCorr_CPU) {
         }
 
         // -------------------------case 1----------------------------------
-        custom_setenv("_ONEDNN_ENABLE_SDP_DECOMP", "0", 1);
+        custom_setenv("_ONEDNN_GRAPH_SDPA_FORCE_PRIMITIVE", "1", 1);
         graph::compiled_partition_t cp1(p);
         ASSERT_EQ(
                 p.compile(&cp1, inputs, outputs, eng), graph::status::success);
@@ -754,7 +755,7 @@ TEST(test_sdp_decomp_execute, F32DistilBertSdpCorr_CPU) {
         strm->wait();
 
         // -------------------------case 2----------------------------------
-        custom_setenv("_ONEDNN_ENABLE_SDP_DECOMP", "1", 1);
+        custom_setenv("_ONEDNN_GRAPH_SDPA_FORCE_PRIMITIVE", "0", 1);
         graph::compiled_partition_t cp2(p);
         ASSERT_EQ(
                 p.compile(&cp2, inputs, outputs, eng), graph::status::success);
@@ -810,7 +811,7 @@ TEST(test_sdp_decomp_execute, Bf16SdpCorr_CPU) {
                     attention_mask_vec[j]);
             g.finalize();
 
-            graph::pass::pass_base_ptr apass = get_pass("float_sdp_fusion");
+            graph::pass::pass_base_ptr apass = get_pass("float_sdp_fusion_cpu");
             apass->run(g);
             ASSERT_EQ(g.get_num_partitions(), 1U);
             auto part = g.get_partitions()[0];
@@ -863,7 +864,7 @@ TEST(test_sdp_decomp_execute, Bf16SdpCorr_CPU) {
             }
 
             // -------------------------case 1----------------------------------
-            custom_setenv("_ONEDNN_ENABLE_SDP_DECOMP", "0", 1);
+            custom_setenv("_ONEDNN_GRAPH_SDPA_FORCE_PRIMITIVE", "1", 1);
             graph::compiled_partition_t cp1(p);
             ASSERT_EQ(p.compile(&cp1, inputs, outputs, eng),
                     graph::status::success);
@@ -879,7 +880,7 @@ TEST(test_sdp_decomp_execute, Bf16SdpCorr_CPU) {
             strm->wait();
 
             // -------------------------case 2----------------------------------
-            custom_setenv("_ONEDNN_ENABLE_SDP_DECOMP", "1", 1);
+            custom_setenv("_ONEDNN_GRAPH_SDPA_FORCE_PRIMITIVE", "0", 1);
             graph::compiled_partition_t cp2(p);
             ASSERT_EQ(p.compile(&cp2, inputs, outputs, eng),
                     graph::status::success);
@@ -933,7 +934,7 @@ TEST(test_sdp_decomp_execute, Bf16DistilBertSdpCorr_CPU) {
                 batch_size, seq_len, num_head, head_dim, transpose_b[i]);
         g.finalize();
 
-        graph::pass::pass_base_ptr apass = get_pass("float_sdp_fusion");
+        graph::pass::pass_base_ptr apass = get_pass("float_sdp_fusion_cpu");
         apass->run(g);
         ASSERT_EQ(g.get_num_partitions(), 1U);
         auto part = g.get_partitions()[0];
@@ -984,7 +985,7 @@ TEST(test_sdp_decomp_execute, Bf16DistilBertSdpCorr_CPU) {
         }
 
         // -------------------------case 1----------------------------------
-        custom_setenv("_ONEDNN_ENABLE_SDP_DECOMP", "0", 1);
+        custom_setenv("_ONEDNN_GRAPH_SDPA_FORCE_PRIMITIVE", "1", 1);
         graph::compiled_partition_t cp1(p);
         ASSERT_EQ(
                 p.compile(&cp1, inputs, outputs, eng), graph::status::success);
@@ -1000,7 +1001,7 @@ TEST(test_sdp_decomp_execute, Bf16DistilBertSdpCorr_CPU) {
         strm->wait();
 
         // -------------------------case 2----------------------------------
-        custom_setenv("_ONEDNN_ENABLE_SDP_DECOMP", "1", 1);
+        custom_setenv("_ONEDNN_GRAPH_SDPA_FORCE_PRIMITIVE", "0", 1);
         graph::compiled_partition_t cp2(p);
         ASSERT_EQ(
                 p.compile(&cp2, inputs, outputs, eng), graph::status::success);
@@ -1093,7 +1094,7 @@ TEST(test_sdp_decomp_execute, Int8SdpCorr_CPU) {
                 inputs_ts.back().fill<uint8_t>();
             }
             // -------------------------case 1----------------------------------
-            custom_setenv("_ONEDNN_ENABLE_SDP_DECOMP", "0", 1);
+            custom_setenv("_ONEDNN_GRAPH_SDPA_FORCE_PRIMITIVE", "1", 1);
             graph::compiled_partition_t cp1(p);
             ASSERT_EQ(p.compile(&cp1, inputs, outputs, eng),
                     graph::status::success);
@@ -1109,7 +1110,7 @@ TEST(test_sdp_decomp_execute, Int8SdpCorr_CPU) {
             strm->wait();
 
             // -------------------------case 2----------------------------------
-            custom_setenv("_ONEDNN_ENABLE_SDP_DECOMP", "1", 1);
+            custom_setenv("_ONEDNN_GRAPH_SDPA_FORCE_PRIMITIVE", "0", 1);
             graph::compiled_partition_t cp2(p);
             ASSERT_EQ(p.compile(&cp2, inputs, outputs, eng),
                     graph::status::success);
@@ -1208,7 +1209,7 @@ TEST(test_sdp_decomp_execute, Int8Bf16SdpCorr_CPU) {
                 inputs_ts.back().fill<uint8_t>();
             }
             // -------------------------case 1----------------------------------
-            custom_setenv("_ONEDNN_ENABLE_SDP_DECOMP", "0", 1);
+            custom_setenv("_ONEDNN_GRAPH_SDPA_FORCE_PRIMITIVE", "1", 1);
             graph::compiled_partition_t cp1(p);
             ASSERT_EQ(p.compile(&cp1, inputs, outputs, eng),
                     graph::status::success);
@@ -1224,7 +1225,7 @@ TEST(test_sdp_decomp_execute, Int8Bf16SdpCorr_CPU) {
             strm->wait();
 
             // -------------------------case 2----------------------------------
-            custom_setenv("_ONEDNN_ENABLE_SDP_DECOMP", "1", 1);
+            custom_setenv("_ONEDNN_GRAPH_SDPA_FORCE_PRIMITIVE", "0", 1);
             graph::compiled_partition_t cp2(p);
             ASSERT_EQ(p.compile(&cp2, inputs, outputs, eng),
                     graph::status::success);
@@ -1315,7 +1316,7 @@ TEST(test_sdp_decomp_execute, Int8DistilBertSdpCorr_CPU) {
             inputs_ts.back().fill<uint8_t>();
         }
         // -------------------------case 1----------------------------------
-        custom_setenv("_ONEDNN_ENABLE_SDP_DECOMP", "0", 1);
+        custom_setenv("_ONEDNN_GRAPH_SDPA_FORCE_PRIMITIVE", "1", 1);
         graph::compiled_partition_t cp1(p);
         ASSERT_EQ(
                 p.compile(&cp1, inputs, outputs, eng), graph::status::success);
@@ -1331,7 +1332,7 @@ TEST(test_sdp_decomp_execute, Int8DistilBertSdpCorr_CPU) {
         strm->wait();
 
         // -------------------------case 2----------------------------------
-        custom_setenv("_ONEDNN_ENABLE_SDP_DECOMP", "1", 1);
+        custom_setenv("_ONEDNN_GRAPH_SDPA_FORCE_PRIMITIVE", "0", 1);
         graph::compiled_partition_t cp2(p);
         ASSERT_EQ(
                 p.compile(&cp2, inputs, outputs, eng), graph::status::success);
@@ -1427,7 +1428,7 @@ TEST(test_sdp_decomp_execute, Int8Bf16DistilBertSdpCorr_CPU) {
             inputs_ts.back().fill<uint8_t>();
         }
         // -------------------------case 1----------------------------------
-        custom_setenv("_ONEDNN_ENABLE_SDP_DECOMP", "0", 1);
+        custom_setenv("_ONEDNN_GRAPH_SDPA_FORCE_PRIMITIVE", "1", 1);
         graph::compiled_partition_t cp1(p);
         ASSERT_EQ(
                 p.compile(&cp1, inputs, outputs, eng), graph::status::success);
@@ -1443,7 +1444,7 @@ TEST(test_sdp_decomp_execute, Int8Bf16DistilBertSdpCorr_CPU) {
         strm->wait();
 
         // -------------------------case 2----------------------------------
-        custom_setenv("_ONEDNN_ENABLE_SDP_DECOMP", "1", 1);
+        custom_setenv("_ONEDNN_GRAPH_SDPA_FORCE_PRIMITIVE", "0", 1);
         graph::compiled_partition_t cp2(p);
         ASSERT_EQ(
                 p.compile(&cp2, inputs, outputs, eng), graph::status::success);
@@ -1540,7 +1541,7 @@ TEST(test_sdp_decomp_execute, MultithreaSdpDecompCorr_CPU) {
         }
 
         // -------------------------case 1----------------------------------
-        custom_setenv("_ONEDNN_ENABLE_SDP_DECOMP", "0", 1);
+        custom_setenv("_ONEDNN_GRAPH_SDPA_FORCE_PRIMITIVE", "1", 1);
         graph::compiled_partition_t cp1(p);
         ASSERT_EQ(
                 p.compile(&cp1, inputs, outputs, eng), graph::status::success);
@@ -1559,6 +1560,7 @@ TEST(test_sdp_decomp_execute, MultithreaSdpDecompCorr_CPU) {
             graph::stream_t *strm_eng;
             dnnl_stream_create(&strm_eng, eng, dnnl_stream_in_order);
             std::vector<test_tensor> outputs_ts;
+            outputs_ts.reserve(partition_outputs.size());
             for (auto &lt : partition_outputs) {
                 outputs_ts.emplace_back(lt, eng);
             }
